@@ -45,30 +45,35 @@ bhit_map <- function(data, well, plate = 96, threshold = 2,
     platemap <- platemap[order(platemap$Row, platemap$Column), ]
 
     check_plate_input(well, plate)
-
-    if (plate == 96L) {
-        # transform into 12*8 matrix (96-well plate)
-        # fills matrix in a row-wise fashion i.e, A01, A02 ...
-        mat_plate_map <- matrix(data,
-                                nrow = 8,
-                                ncol = 12,
-                                byrow = TRUE)
+    if (plate == 6L) {
+        nrow <- 3
+        ncol <- 2
+    } else if (plate == 12L) {
+        nrow <- 4
+        ncol <- 3
+    } else if (plate == 24L) {
+        nrow <- 6
+        ncol <- 4
+    } else if (plate == 48L) {
+        nrow <- 8
+        ncol <- 6
+    } else if (plate == 96L) {
+        nrow <- 8
+        ncol <- 12
     } else if (plate == 384L) {
-        # transform into 24*16 matrix (384-well plate)
-        # fills matrix in a row-wise fashion, i.e A01, A02 ...
-        mat_plate_map <- matrix(data,
-                                nrow = 16,
-                                ncol = 24,
-                                byrow = TRUE)
+        nrow <- 16
+        ncol <- 24
     } else if (plate == 1536L) {
-    mat_plate_map <- matrix(data,
-                            nrow = 32,
-                            ncol = 24,
-                            byrow = TRUE)
+        nrow <- 32
+        ncol <- 48
     } else {
-        stop("Not a plate format.\nArgument 'plate' should be 96, 384 or 1536.",
+       stop("Not a plate format.\nArgument 'plate' should be 6, 12, 24, 48, 96, 384 or 1536.",
              call. = FALSE)
     }
+    mat_plate_map <- matrix(data,
+                            nrow = nrow,
+                            ncol = ncol,
+                            byrow = TRUE)
 
     # median polish of the data
     data_pol <- medpolish(mat_plate_map, eps = eps, maxiter = maxiter,
@@ -114,25 +119,43 @@ bhit_map <- function(data, well, plate = 96, threshold = 2,
     my_cols <- brewer.pal(3, palette)
     my_colours <- c(hit = my_cols[1], neg_hit = my_cols[3], null = my_cols[2])
 
-    if (plate == 96){
+    if (plate == 6L){
+        # produce a 6-well plate map layout in ggplot
+        plt <- plt6(platemap, ...) +
+            scale_fill_manual("hit", values = my_colours) +
+            theme_bw()
+    } else if (plate == 12L){
+        # produce a 12-well plate map layout in ggplot
+        plt <- plt12(platemap, ...) +
+            scale_fill_manual("hit", values = my_colours) +
+            theme_bw()
+    } else if (plate == 24L){
+        # produce a 24-well plate map layout in ggplot
+        plt <- plt24(platemap, ...) +
+            scale_fill_manual("hit", values = my_colours) +
+            theme_bw()
+    } else if (plate == 48L){
+        # produce a 48-well plate map layout in ggplot
+        plt <- plt48(platemap, ...) +
+            scale_fill_manual("hit", values = my_colours) +
+            theme_bw()
+    } else if (plate == 96L){
         # produce a 96-well plate map layout in ggplot
         plt <- plt96(platemap, ...) +
             scale_fill_manual("hit", values = my_colours) +
             theme_bw()
-
-    } else if (plate == 384) {
+    } else if (plate == 384L) {
         # produce a 384-well plate map layout in ggplot
         plt <- plt384(platemap, ...) +
             scale_fill_manual("hit", values = my_colours) +
             theme_bw()
-
     } else if (plate == 1536L) {
         plt <- plt1536(platemap, ...) +
            scale_fill_manual("hit", values = my_colours) +
            theme_bw()
 
     } else {
-        stop("Not a valid plate format. Either 96, 384 or 1536.", call. = FALSE)
+        stop("Not a valid plate format. Either 6, 12, 24, 48, 96, 384 or 1536.", call. = FALSE)
     }
     return(plt)
 }
